"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("@angular/core");
var masks_service_1 = require("../masks.service");
var _ = require("lodash");
var validators_service_1 = require("../validators.service");
var BaseElement = /** @class */ (function () {
    function BaseElement() {
        this.hasMask = false;
        this._mask = null;
        this._fn_onKeyPress = [];
        this._fn_onKeyUp = [];
        this._fn_onChange = [];
        this._fn_onBlur = [];
        this.validatorsService = new validators_service_1.ValidatorsService();
        this.masksService = new masks_service_1.MasksService();
    }
    BaseElement.prototype.ngOnInit = function () {
        this.registerOutputEvents();
    };
    BaseElement.prototype.parseData = function () { };
    BaseElement.prototype.registerOutputEvents = function () {
        var _this = this;
        if (this.data.events) {
            Object.keys(this.data.events).forEach(function (event) {
                _this.registerEvent(event, function ($event, value) {
                    _this.data.events[event].emit({
                        value: value,
                        controlName: _this.data.controlName
                    });
                });
            });
        }
    };
    BaseElement.prototype.registerEvent = function (name, fn) {
        if (this['_fn_' + name] && this['_fn_' + name] instanceof Array) {
            this['_fn_' + name].push(fn);
        }
    };
    BaseElement.prototype.triggerEvent = function (name, $event, value) {
        if (this['_fn_' + name] && this['_fn_' + name] instanceof Array) {
            this['_fn_' + name].forEach(function (fn) {
                if (!$event.propagation_stopped && !$event.defaultPrevented) {
                    fn($event, value);
                }
            });
        }
    };
    BaseElement.prototype.getEventValue = function ($event) {
        if ($event) {
            if (typeof $event.value != 'undefined') {
                return $event.value;
            }
            if ($event.target && typeof $event.target.value != 'undefined') {
                return $event.target.value;
            }
        }
        return $event;
    };
    BaseElement.prototype.onKeyUp = function ($event) {
        this.triggerEvent('onKeyUp', $event, this.getEventValue($event));
    };
    BaseElement.prototype.onKeyPress = function ($event) {
        this.triggerEvent('onKeyPress', $event, this.getEventValue($event));
    };
    BaseElement.prototype.onChange = function ($event) {
        this.triggerEvent('onChange', $event, this.getEventValue($event));
    };
    BaseElement.prototype.onBlur = function ($event) {
        this.triggerEvent('onBlur', $event, this.getEventValue($event));
    };
    Object.defineProperty(BaseElement.prototype, "value", {
        get: function () {
            if (this.hasMask && this.data.config.mask == 'currency') {
                return this.applyMask(this.data.model[this.data.field.name]);
            }
            return this.data.model[this.data.field.name];
        },
        set: function (val) {
            this.data.model[this.data.field.name] = this.unmask(val);
        },
        enumerable: true,
        configurable: true
    });
    BaseElement.prototype.createMask = function () {
        if (this.data.config && this.data.config.mask) {
            this.hasMask = true;
            if (this.data.config.mask != 'currency') {
                var args = this.masksService.getMask(this.data.config.mask);
                if (args instanceof Array || typeof args == 'function') {
                    return { mask: args, guide: false };
                }
                return args;
            }
        }
        return { mask: false };
    };
    Object.defineProperty(BaseElement.prototype, "mask", {
        get: function () {
            if (this._mask == null) {
                this._mask = this.createMask();
            }
            return this._mask;
        },
        enumerable: true,
        configurable: true
    });
    BaseElement.prototype.applyMask = function (val) {
        if (val && this.hasMask) {
            val = this.masksService.applyMask(this.data.config.mask, val);
        }
        return val;
    };
    BaseElement.prototype.unmask = function (val) {
        if (val && this.hasMask && this.data.config.unmask !== false) {
            val = this.masksService.unmask(this.data.config.mask, val);
        }
        return val;
    };
    BaseElement.prototype.hasHint = function (align) {
        if (_.has(this.data.config, 'hint')) {
            return _.has(this.data.config.hint, align);
        }
        return false;
    };
    BaseElement.prototype.getHint = function (align) {
        var hint = this.data.config.hint[align];
        if (hint) {
            var value = '';
            if (this.data.model[this.data.field.name]) {
                value = this.data.model[this.data.field.name];
            }
            hint = _.replace(hint, ':value', value);
            hint = _.replace(hint, ':length', value.length + '');
            return hint;
        }
        else {
            return '';
        }
    };
    BaseElement.decorators = [
        { type: core_1.Injectable },
    ];
    /** @nocollapse */
    BaseElement.ctorParameters = function () { return []; };
    BaseElement.propDecorators = {
        'data': [{ type: core_1.Input, args: ['data',] },],
    };
    return BaseElement;
}());
exports.BaseElement = BaseElement;
//# sourceMappingURL=base.js.map