"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("@angular/core");
var services_1 = require("../../../../services");
var validator_1 = require("./validator");
var mimetypes_1 = require("./mimetypes");
var UploaderItemComponent = /** @class */ (function () {
    function UploaderItemComponent(dialogService, cd) {
        this.dialogService = dialogService;
        this.cd = cd;
        this._showDownloadButton = false;
        this._validator = new validator_1.Validator();
        this.fileInfo = {};
        this.selectable = true;
        this.download = true;
        this.removable = true;
        this.viewMode = 'grid';
        this.draggable = false;
        this.validators = {};
        this.urlParams = {};
        this.onClick = new core_1.EventEmitter();
        this.onDestroy = new core_1.EventEmitter();
        this.onFailUpload = new core_1.EventEmitter();
        this.onSuccessfullyUpload = new core_1.EventEmitter();
    }
    Object.defineProperty(UploaderItemComponent.prototype, "isUploading", {
        get: function () {
            return this._isUploading;
        },
        set: function (val) {
            this._isUploading = val;
            this.cd.detectChanges();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(UploaderItemComponent.prototype, "error", {
        get: function () {
            return this._error;
        },
        set: function (val) {
            this._error = val;
            this.cd.detectChanges();
        },
        enumerable: true,
        configurable: true
    });
    UploaderItemComponent.prototype.ngOnInit = function () {
        var _this = this;
        this._mimeTypes = new mimetypes_1.Mimetypes();
        this.fileInfo = this.getFileInfo();
        this.item.fileComponent = this;
        this._intervalCheckChanges = setInterval(function () {
            var val = _this.download && !_this.isUploading && !_this.error && _this.item.file.download_link;
            if (_this._showDownloadButton != val) {
                _this._showDownloadButton = val;
                _this.cd.detectChanges();
            }
        }, 100);
    };
    UploaderItemComponent.prototype.ngOnDestroy = function () {
        if (this._intervalCheckChanges) {
            clearInterval(this._intervalCheckChanges);
        }
    };
    UploaderItemComponent.prototype.isUploaded = function () {
        return ['ok', 'uploaded'].indexOf(this.item.status) > -1;
    };
    UploaderItemComponent.prototype.bytesToSize = function (bytes) {
        var sizes = ['Bytes', 'KB', 'MB', 'GB', 'TB'];
        if (bytes == 0) {
            return '0 Byte';
        }
        var i = Math.floor(Math.log(bytes) / Math.log(1024));
        return Math.round(bytes / Math.pow(1024, i)).toString() + ' ' + sizes[i];
    };
    ;
    UploaderItemComponent.prototype.getFileInfo = function () {
        var file = this.item.file;
        var d = new Date(file.lastModifiedDate);
        return {
            name: file.name,
            size: this.bytesToSize(file.size),
            sent_date: d.toLocaleDateString() + ' ' + d.toLocaleTimeString()
        };
    };
    UploaderItemComponent.prototype.ngAfterViewInit = function () {
        this._mimeTypes.setPreviewImage(this.item.file, this.preview.nativeElement);
        if (this.item.file instanceof File) {
            this.upload();
        }
    };
    UploaderItemComponent.prototype.click = function () {
        if (!this.isUploading && !this.error && this.selectable) {
            this.onClick.emit(this.item);
        }
    };
    UploaderItemComponent.prototype.upload = function () {
        var _this = this;
        if (!this._validator.validate(this.item.file, this.validators)) {
            this.error = {
                error: 'Arquivo inválido!',
                messages: { file: this._validator.errors }
            };
            this.onFailUpload.emit(this.item);
        }
        else {
            this.isUploading = true;
            this.uploaderService
                .upload(this.item.file, this.urlParams)
                .then(function (result) {
                _this.isUploading = false;
                _this.onSuccessfullyUpload.emit(result.body.data);
            }, function (res) {
                _this.isUploading = false;
                try {
                    _this.error = res.json();
                }
                catch (error) {
                    _this.error = { error: 'something went wrong' };
                }
                _this.onFailUpload.emit(_this.item);
            });
        }
    };
    UploaderItemComponent.prototype.showError = function ($event) {
        var _this = this;
        if ($event) {
            $event.preventDefault();
        }
        var html = "<h3>" + this.error.error + "</h3>";
        if (this.error.messages && this.error.messages['file']) {
            var li_1 = '';
            this.error.messages['file'].forEach(function (msg) {
                li_1 += "<li>" + msg + "</li>";
            });
            html += "<ul style=\"text-align: left;padding-left: 75px;\">" + li_1 + "</ul>";
        }
        this.dialogService
            .error({
            html: html,
            onClose: function () {
                _this.remove();
            }
        });
    };
    UploaderItemComponent.prototype.remove = function (event) {
        var _this = this;
        if (event) {
            event.stopPropagation();
        }
        if (this.deleteMode == 'remove_from_server' && this.isUploaded()) {
            this.isUploading = true;
            this.uploaderService.remove(this.item.file, this.urlParams)
                .then(function () {
                _this.onDestroy.emit(_this.item);
                _this.isUploading = false;
            }, function () {
                _this.isUploading = false;
            });
        }
        else {
            this.onDestroy.emit(this.item);
        }
    };
    UploaderItemComponent.decorators = [
        { type: core_1.Component, args: [{
                    selector: 'gc-form-element-file',
                    template: "\n        <div class=\"container-file{{ error ? ' has-error' : '' }} {{ viewMode }} {{ isUploading ? 'uploading' : '' }}\" >\n            \n            <mat-icon *ngIf=\"draggable\" class=\"drag-handle draggable\">drag_handle</mat-icon>\n            \n            <div class=\"file\" >\n                <div #preview class=\"preview\" (click)=\"click()\"></div>\n                <div class=\"info align-self-end\">\n                    <p class=\"text-truncate\">{{ fileInfo.name }}</p>\n                    <p class=\"text-truncate\">{{ fileInfo.size }}</p>\n                    <p class=\"text-truncate\">{{ fileInfo.sent_date }}</p>\n                </div>\n                \n                <i *ngIf=\"selectable\" class=\"material-icons check {{ item.selected ? 'selected' : ''}}\" color=\"primary\" (click)=\"select()\">check_circle</i>\n                \n                <div *ngIf=\"_showDownloadButton\" class=\"downloader d-flex\">\n                    <a class=\"btn btn-sm btn-block btn-light align-self-center\" [href]=\"item.file.download_link\" target=\"_blank\" [download]=\"fileInfo.name\">Download</a>\n                </div>\n            </div>\n\n            <ms-loading-overlay [isLoading]=\"true\"></ms-loading-overlay>\n\n            <i class=\"material-icons error\" (click)=\"showError($event)\">error</i>\n        </div>\n    ",
                    styles: ["\n        .container-file {\n            position: relative;\n        }\n\n        .container-file .error {\n            font-size: 30px;\n            display: none;\n            position: absolute;\n            top: 50%;\n            left: 50%;\n            margin-left: -15px;\n            margin-top: -15px;\n            color: white;\n            cursor: pointer;\n            z-index: 2;\n        }\n\n        .container-file.has-error .error {\n            display: block;\n        }\n\n        .container-file .remove {\n            position: absolute;\n            left: 50%;\n            top: 50%;\n            -webkit-transform: translate(-50%, -50%);\n            -moz-transform: translate(-50%, -50%);\n            -ms-transform: translate(-50%, -50%);\n            -o-transform: translate(-50%, -50%);\n            transform: translate(-50%, -50%);\n            color: #ff5854;\n            font-size: 25px;\n            display: none;\n        }\n\n        .container-file:hover .remove {\n            display: block;\n            cursor: pointer;\n        }\n\n        .container-file ms-loading-overlay {\n            display: none;\n            position: absolute;\n            top: 0;\n            left: 0;\n            width: 100%;\n        }\n\n        .container-file.uploading ms-loading-overlay {\n            display: block;\n        }\n\n        .container-file.has-error::before,\n        .container-file.uploading::before {\n            content: '';\n            position: absolute;\n            background-color: rgba(110, 110, 110, 0.4);\n            top: 0;\n            left: 0;\n            width: 100%;\n            height: 100%;\n            z-index: 1;\n        }\n\n        .container-file .file {\n            position: relative;\n        }\n\n        .container-file .file .check {\n            position: absolute;\n            right: -12px;\n            top: -12px;\n            font-size: 25px;\n            cursor: pointer;\n            display: none;\n        }\n\n        .container-file .file .check.selected {\n            color: #61b0ff;\n            display: block;\n        }\n\n        .container-file .file .preview {\n            width: 100%;\n            overflow: hidden;\n            position: relative;\n        }\n\n        .container-file .file .preview:after {\n            content: \"\";\n            display: block;\n            padding-bottom: 100%;\n        }\n\n        .container-file .file .preview > * {\n            width: 100%;\n            position: absolute;\n            top: 50%;\n            left: 50%;\n            transform: translate(-50%, -50%);\n            max-width: 100%;\n        }\n\n        .container-file .file .info {\n            max-width: calc(100% - 50px);\n        }\n\n        .container-file .file .info p {\n            margin-bottom: 0;\n            font-size: 12px;\n        }\n\n        /* GRID */\n        .container-file.grid {\n            border-radius: 3px;\n            margin-bottom: 15px;\n        }\n\n        .container-file.grid .file,\n        .container-file.grid .file .preview,\n        .container-file.grid.has-error::before {\n            border-radius: inherit;\n        }\n\n        .container-file.grid .file .info {\n            display: none;\n        }\n\n        /* LIST */\n        .col-list {\n            width: 100%;\n            padding-left: 15px;\n            padding-right: 15px;\n        }\n\n        .container-file {\n            margin-bottom: 5px;\n        }\n\n        .container-file.list {\n            width: 100%;\n            padding: 15px;\n        }\n\n        .container-file.list .file {\n            display: flex;\n            position: relative;\n        }\n\n        .container-file.list .file .preview {\n            max-width: 50px;\n        }\n\n        .container-file.list .file .info {\n            margin-left: 15px;\n        }\n\n        .container-file.list .file .check {\n            left: 35px;\n            right:auto;\n        }\n\n        .container-file.list .file .downloader {\n            margin-left: 15px;\n        }\n    "],
                    encapsulation: core_1.ViewEncapsulation.None
                },] },
    ];
    /** @nocollapse */
    UploaderItemComponent.ctorParameters = function () { return [
        { type: services_1.DialogService, },
        { type: core_1.ChangeDetectorRef, },
    ]; };
    UploaderItemComponent.propDecorators = {
        'preview': [{ type: core_1.ViewChild, args: ['preview',] },],
        'fileName': [{ type: core_1.ViewChild, args: ['fileName',] },],
        'fileSize': [{ type: core_1.ViewChild, args: ['fileSize',] },],
        'fileSentDate': [{ type: core_1.ViewChild, args: ['fileSentDate',] },],
        'item': [{ type: core_1.Input, args: ['item',] },],
        'selectable': [{ type: core_1.Input, args: ['selectable',] },],
        'download': [{ type: core_1.Input, args: ['download',] },],
        'removable': [{ type: core_1.Input, args: ['removable',] },],
        'viewMode': [{ type: core_1.Input, args: ['viewMode',] },],
        'draggable': [{ type: core_1.Input, args: ['draggable',] },],
        'validators': [{ type: core_1.Input, args: ['validators',] },],
        'urlParams': [{ type: core_1.Input, args: ['urlParams',] },],
        'deleteMode': [{ type: core_1.Input, args: ['deleteMode',] },],
        'uploaderService': [{ type: core_1.Input, args: ['uploaderService',] },],
        'onClick': [{ type: core_1.Output, args: ['onClick',] },],
        'onDestroy': [{ type: core_1.Output, args: ['onDestroy',] },],
        'onFailUpload': [{ type: core_1.Output, args: ['onFailUpload',] },],
        'onSuccessfullyUpload': [{ type: core_1.Output, args: ['onSuccessfullyUpload',] },],
    };
    return UploaderItemComponent;
}());
exports.UploaderItemComponent = UploaderItemComponent;
//# sourceMappingURL=file.component.js.map