"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var FilePreview = /** @class */ (function () {
    function FilePreview(file) {
        this.status = 'reading';
        this.fn = [];
        this.index = 0;
        this.read(file);
    }
    FilePreview.prototype.read = function (file) {
        var _this = this;
        var reader = new FileReader();
        reader.readAsDataURL(file);
        reader.onload = function (e) {
            _this.status = 'read';
            _this.src = e.currentTarget.result;
            _this.exec();
        };
    };
    FilePreview.prototype.exec = function () {
        for (var i = this.fn.length; this.index < i; this.index++) {
            this.fn[this.index](this.src);
        }
    };
    FilePreview.prototype.onLoad = function (fn) {
        this.fn.push(fn);
        if (this.status == 'read') {
            this.exec();
        }
    };
    return FilePreview;
}());
var Mimetypes = /** @class */ (function () {
    function Mimetypes() {
        this.previews = {};
    }
    Mimetypes.prototype.image = function () {
        return [
            'image/png',
            'image/jpeg',
            'image/jpg',
            'image/gif',
            'image/svg',
            'image/svg+xml'
        ];
    };
    Mimetypes.prototype.video = function () {
        return [
            'video/mp4'
        ];
    };
    Mimetypes.prototype.audio = function () {
        return [
            'audio/mpeg3',
            'audio/x-mpeg-3',
            'video/mpeg',
            'video/x-mpeg',
            'audio/mp3',
            'audio/mpeg'
        ];
    };
    Mimetypes.prototype.doc = function () {
        return [
            'application/msword',
            'application/vnd.openxmlformats-officedocument.wordprocessingml.document'
        ];
    };
    Mimetypes.prototype.pdf = function () {
        return [
            'application/pdf',
            'application/x-pdf'
        ];
    };
    Mimetypes.prototype.ppt = function () {
        return [
            'application/mspowerpoint',
            'application/powerpoint',
            'application/vnd.ms-powerpoint',
            'application/x-mspowerpoint	',
            'application/vnd.ms-powerpoint',
            'application/vnd.openxmlformats-officedocument.presentationml.presentation'
        ];
    };
    Mimetypes.prototype.txt = function () {
        return [
            'text/plain',
            'text/rtf'
        ];
    };
    Mimetypes.prototype.xls = function () {
        return [
            'application/excel',
            'application/vnd.ms-excel',
            'application/x-excel',
            'application/x-msexcel',
            'application/vnd.openxmlformats-officedocument.spreadsheetml.sheet'
        ];
    };
    Mimetypes.prototype.zip = function () {
        return [
            'application/x-compressed',
            'application/x-zip-compressed',
            'application/zip',
            'multipart/x-zip'
        ];
    };
    Mimetypes.prototype.isMedia = function (file) {
        return this.isImage(file) || this.isVideo(file) || this.isAudio(file);
    };
    Mimetypes.prototype.isImage = function (file) {
        return this.image().indexOf(file.type) > -1;
    };
    Mimetypes.prototype.isVideo = function (file) {
        return this.video().indexOf(file.type) > -1;
    };
    Mimetypes.prototype.isAudio = function (file) {
        return this.audio().indexOf(file.type) > -1;
    };
    Mimetypes.prototype.isDoc = function (file) {
        return this.doc().indexOf(file.type) > -1;
    };
    Mimetypes.prototype.isPdf = function (file) {
        return this.pdf().indexOf(file.type) > -1;
    };
    Mimetypes.prototype.isPpt = function (file) {
        return this.ppt().indexOf(file.type) > -1;
    };
    Mimetypes.prototype.isTxt = function (file) {
        return this.txt().indexOf(file.type) > -1;
    };
    Mimetypes.prototype.isXls = function (file) {
        return this.xls().indexOf(file.type) > -1;
    };
    Mimetypes.prototype.isZip = function (file) {
        return this.zip().indexOf(file.type) > -1;
    };
    Mimetypes.prototype.loadPreview = function (file, fn) {
        if (!this.previews[file.name]) {
            this.previews[file.name] = new FilePreview(file);
        }
        this.previews[file.name].onLoad(fn);
    };
    Mimetypes.prototype.setPreviewImage = function (file, node) {
        if (this.isImage(file)) {
            var image_1 = document.createElement('IMG');
            image_1.className = 'img-fluid img-responsive w-100';
            node.appendChild(image_1);
            if (file instanceof File) {
                this.loadPreview(file, function (src) {
                    image_1.src = src;
                    node.appendChild(image_1);
                });
            }
            else {
                image_1.src = file.src;
            }
        }
        else if (this.isVideo(file)) {
            var video_1 = document.createElement('VIDEO');
            video_1.innerHTML = 'Seu navegador não suporta o elemento <code>video</code>.';
            node.appendChild(video_1);
            var playing_1 = false;
            video_1.onclick = function (e) {
                e.stopPropagation();
                if (playing_1) {
                    video_1.pause();
                    playing_1 = false;
                }
                else {
                    playing_1 = true;
                    video_1.play();
                }
            };
            if (file instanceof File) {
                this.loadPreview(file, function (src) {
                    video_1.src = src;
                });
            }
            else {
                video_1.src = file.src;
            }
        }
        else if (this.isAudio(file)) {
            this.loadPreview(file, function (src) {
                var audio = document.createElement('AUDIO');
                audio.src = src;
                audio.innerHTML = 'Seu navegador não suporta o elemento <code>audio</code>.';
                node.appendChild(audio);
            });
        }
        else {
            var src = '/assets/uploader/icon_undefined.png';
            if (this.isDoc(file)) {
                src = '/assets/uploader/icon_doc.ico';
            }
            else if (this.isPdf(file)) {
                src = '/assets/uploader/icon_pdf.ico';
            }
            else if (this.isPpt(file)) {
                src = '/assets/uploader/icon_ppt.ico';
            }
            else if (this.isTxt(file)) {
                src = '/assets/uploader/icon_txt.ico';
            }
            else if (this.isXls(file)) {
                src = '/assets/uploader/icon_xls.ico';
            }
            else if (this.isZip(file)) {
                src = '/assets/uploader/icon_zip.ico';
            }
            var image = document.createElement('IMG');
            image.src = src;
            image.className = 'img-fluid img-responsive';
            node.appendChild(image);
        }
    };
    Mimetypes.prototype.getMimeTypes = function () {
        var _this = this;
        var types = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            types[_i] = arguments[_i];
        }
        var arr = [];
        types.forEach(function (type) {
            if (typeof _this[type] == 'function') {
                arr = arr.concat(_this[type]());
            }
        });
        return arr.join(',');
    };
    return Mimetypes;
}());
exports.Mimetypes = Mimetypes;
//# sourceMappingURL=mimetypes.js.map