"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("@angular/core");
var uploader_service_1 = require("./uploader.service");
var base_1 = require("../base");
var mimetypes_1 = require("./mimetypes");
var UploaderComponent = /** @class */ (function (_super) {
    __extends(UploaderComponent, _super);
    function UploaderComponent(injector) {
        var _this = _super.call(this) || this;
        _this.injector = injector;
        _this.hasChanges = false;
        _this.hasPendingUpload = false;
        _this.hasOrderChanges = false;
        _this.hasSelectedItems = false;
        _this.hasUploadFails = false;
        _this.mimeTypes = new mimetypes_1.Mimetypes();
        _this.config = {
            info: '',
            multi: true,
            urlParams: null,
            removable: true,
            deleteMode: 'mark_as_deleted',
            removeDeletedFiles: true,
            download: true,
            viewMode: 'grid',
            validators: {
                types: 'image',
                size: null
            },
            gridClass: 'col-xs-6 col-sm-4 col-md-3 col-lg-2 col-xl-1',
            listClass: 'col-list',
            uploaderService: uploader_service_1.UploaderService
        };
        return _this;
    }
    Object.defineProperty(UploaderComponent.prototype, "accept", {
        get: function () {
            return this.config.validators && this.config.validators.types ? this.mimeTypes.getMimeTypes(this.config.validators.types) : '';
        },
        enumerable: true,
        configurable: true
    });
    UploaderComponent.prototype.ngOnInit = function () {
        _super.prototype.ngOnInit.call(this);
        this.hasPendingUpload = false;
        this.hasSelectedItems = false;
        this.hasUploadFails = false;
        this.hasChanges = false;
        this.items = [];
        this.uploaderService = this.injector.get(this.config.uploaderService);
        var files = [];
        if (typeof this.config.files !== 'undefined') {
            files = this.config.files;
        }
        else {
            if (typeof this.data.model.getFiles == 'function') {
                files = this.data.model.getFiles();
            }
            else if (this.data.model[this.data.field.name] instanceof Array) {
                files = this.data.model[this.data.field.name];
            }
        }
        this.items = files.map(function (file, index) {
            return {
                status: 'ok',
                selected: false,
                index: index,
                file: file
            };
        });
        this.normalizeItems();
        this.checkUploadFails();
    };
    UploaderComponent.prototype.ngOnDestroy = function () {
        if (this.intervalCheckFails) {
            clearInterval(this.intervalCheckFails);
        }
    };
    UploaderComponent.prototype.parseData = function () {
        if (this.data.config) {
            for (var index in this.data.config) {
                this.config[index] = this.data.config[index];
            }
        }
    };
    UploaderComponent.prototype.normalizeItems = function () {
        if (!(this.items instanceof Array)) {
            this.items = [this.items];
        }
        if (!this.config.multi && !this.items[0]) {
            this.items.push(this.noImageItem());
        }
    };
    UploaderComponent.prototype.viewMode = function (mode) {
        this.config.viewMode = mode;
    };
    UploaderComponent.prototype.pickupFiles = function ($event) {
        this.inputEl.nativeElement.click();
    };
    UploaderComponent.prototype.upload = function (event) {
        var inputEl = this.inputEl.nativeElement;
        if (!inputEl.files || inputEl.files.length === 0) {
            return;
        }
        var items = inputEl.files;
        if (this.config.multi) {
            for (var i = 0; i < items.length; i++) {
                this.items.push({
                    status: 'uploading',
                    selected: false,
                    index: this.items.length,
                    file: items[i]
                });
            }
        }
        else {
            this.items = [{
                    status: 'uploading',
                    selected: false,
                    index: 0,
                    file: items[0]
                }];
        }
        inputEl.value = '';
        this.checkPending();
    };
    UploaderComponent.prototype.checkChanges = function () {
        this.hasChanges = this.hasPendingUpload || this.hasOrderChanges;
        if (this.hasChanges && typeof this.config.onChange == 'function') {
            this.config.onChange(this.items);
        }
    };
    UploaderComponent.prototype.checkPending = function () {
        var pending = false;
        for (var i = 0, j = this.items.length; i < j; i++) {
            if (this.items[i].status == 'pending') {
                pending = true;
                break;
            }
        }
        this.hasPendingUpload = pending;
    };
    UploaderComponent.prototype.checkSelected = function () {
        var selected = false;
        for (var i = 0, j = this.items.length; i < j; i++) {
            if (this.items[i].selected) {
                selected = true;
                break;
            }
        }
        this.hasSelectedItems = selected;
    };
    UploaderComponent.prototype.checkUploadFails = function () {
        var _this = this;
        if (this.intervalCheckFails) {
            clearInterval(this.intervalCheckFails);
        }
        this.intervalCheckFails = setInterval(function () {
            var fails = false;
            for (var i = 0, j = _this.items.length; i < j; i++) {
                if (_this.items[i].status == 'upload_fail') {
                    fails = true;
                    break;
                }
            }
            _this.hasUploadFails = fails;
        }, 100);
    };
    UploaderComponent.prototype.removeUploadFails = function () {
        this.items = this.items.filter(function (item) {
            return item.status != 'upload_fail';
        });
        this.normalizeItems();
    };
    UploaderComponent.prototype.writeValue = function () {
        var data;
        if (this.config.multi) {
            data = this.items
                .filter(function (item) {
                return (item.status == 'uploaded' || item.status == 'ok' || item.status == 'deleted');
            })
                .map(function (item) {
                return item.file;
            });
        }
        else {
            if (this.items[0] && this.items[0].status == 'uploaded') {
                data = this.items[0].file;
            }
            else {
                data = null;
            }
        }
        if (typeof this.config.writeWith == 'function') {
            this.config.writeWith(data);
        }
        else {
            this.data.model[this.data.field.name] = data;
        }
    };
    UploaderComponent.prototype.noImageItem = function () {
        return {
            status: 'noimage',
            selected: false,
            index: this.items.length,
            file: {
                src: 'assets/uploader/noimage.png'
            }
        };
    };
    UploaderComponent.prototype.destroySelected = function () {
        if (this.config.deleteMode == 'remove_from_server') {
            this.items.forEach(function (item) {
                if (item.selected && item.fileComponent) {
                    item.fileComponent.remove();
                }
            });
        }
        else {
            this.items.forEach(function (item) {
                if (item.selected) {
                    item.status = 'deleted';
                }
            });
            if (this.config.removeDeletedFiles) {
                this.items = this.items.filter(function (item) {
                    return item.status != 'deleted';
                });
            }
            this.normalizeItems();
            this.checkSelected();
            this.checkChanges();
            this.writeValue();
        }
    };
    /* CALLBACKS METHODS */
    UploaderComponent.prototype.onDestroy = function (item, $event) {
        item.status = 'deleted';
        if (this.config.deleteMode == 'remove_from_server' || this.config.removeDeletedFiles) {
            this.items = this.items.filter(function (i) {
                return i.index != item.index;
            });
        }
        this.normalizeItems();
        this.checkSelected();
        this.checkChanges();
        this.writeValue();
    };
    UploaderComponent.prototype.onClick = function (item) {
        if (this.config.multi) {
            item.selected = !item.selected;
            this.checkSelected();
            if (typeof this.config.onSelect == 'function') {
                this.config.onSelect(item);
            }
        }
        else {
            this.pickupFiles();
        }
    };
    UploaderComponent.prototype.onFailUpload = function (item, $event) {
        item.status = 'upload_fail';
    };
    UploaderComponent.prototype.onSuccessfullyUpload = function (item, $event) {
        if (typeof this.config.onSuccessfullyUpload == 'function') {
            $event = this.config.onSuccessfullyUpload($event) || $event;
        }
        item.status = 'uploaded';
        item.file = $event;
        this.checkPending();
        this.checkChanges();
        this.writeValue();
    };
    UploaderComponent.decorators = [
        { type: core_1.Component, args: [{
                    selector: 'gc-form-element-uploader',
                    template: "\n        <ng-container *ngIf=\"config.multi\">\n            <div class=\"gc-form-element-uploader row mx-0 align-items-center mb-3\">\n                <div class=\"col mr-auto info\">\n                    {{ config.info }}\n                </div>\n\n                <div *ngIf=\"config.multi\" class=\"col-auto\">\n                    <div class=\"btn-group\" role=\"group\" aria-label=\"Basic example\">\n                        <button type=\"button\" style=\"line-height: 0\" class=\"btn btn-light btn-sm {{config.viewMode == 'grid' ? 'active' : '' }}\" (click)=\"viewMode('grid')\">\n                            <i class=\"material-icons\">grid_on</i>\n                        </button>\n\n                        <button type=\"button\" style=\"line-height: 0\" class=\"btn btn-light btn-sm {{config.viewMode == 'list' ? 'active' : '' }}\" (click)=\"viewMode('list')\">\n                            <i class=\"material-icons\">view_list</i>\n                        </button>\n                    </div>\n                </div>\n\n                <div class=\"col-auto\">\n                    <div class=\"row\">\n                        <div class=\"col-auto\">\n                            <button mat-button color=\"warn\" (click)=\"removeUploadFails()\" *ngIf=\"hasUploadFails\">\n                                Remove Upload Fails\n                            </button>\n                        </div>\n                        <div class=\"col-auto\" *ngIf=\"config.removable\">\n                            <button mat-icon-button color=\"warn\" (click)=\"destroySelected()\" [disabled]=\"!hasSelectedItems\">\n                                <i class=\"material-icons\">delete</i>\n                            </button>\n                        </div>\n                        <div class=\"col-auto\">\n                            <button type=\"button\" mat-icon-button color=\"primary\" (click)=\"pickupFiles($event)\">\n                                <i class=\"material-icons\">file_upload</i>\n                            </button>\n                        </div>\n                    </div>\n                </div>\n            </div>\n\n        </ng-container>\n\n        <div *ngIf=\"items\" class=\"row container-items mx-0 py-3\">\n            <div *ngFor=\"let item of items\" class=\"{{ config.viewMode == 'grid' ? config.gridClass : config.listClass }}\">\n                \n                <ng-container *ngIf=\"item.status != 'deleted'\">\n                    <gc-form-element-file\n                        class=\"d-block\"\n                        (onClick)=\"onClick(item, $event)\"\n                        (onDestroy)=\"onDestroy(item, $event)\"\n                        (onFailUpload)=\"onFailUpload(item, $event)\"\n                        (onSuccessfullyUpload)=\"onSuccessfullyUpload(item, $event)\"\n                        [uploaderService]=\"uploaderService\"\n                        [viewMode]=\"config.viewMode\"\n                        [removable]=\"config.removable\"\n                        [download]=\"config.download\"\n                        [selectable]=\"config.multi\"\n                        [validators]=\"config.validators\"\n                        [urlParams]=\"config.urlParams\"\n                        [deleteMode]=\"config.deleteMode\"\n                        [item]=\"item\"\n                    >\n                    </gc-form-element-file>\n                </ng-container>\n            </div>\n        </div>\n\n        <input style=\"width: 0;height: 0;\" (change)=\"upload($event)\" [accept]=\"accept\" type=\"file\" [multiple]=\"config.multi\" #fileInput>\n    ",
                    styles: ["\n        gc-form-element-uploader{\n            display: block;\n            height:100%;\n        }\n        .container-items{\n            height: calc(100% - 55px);\n            overflow-y: auto;\n        }\n    "],
                    encapsulation: core_1.ViewEncapsulation.None
                },] },
    ];
    /** @nocollapse */
    UploaderComponent.ctorParameters = function () { return [
        { type: core_1.Injector, },
    ]; };
    UploaderComponent.propDecorators = {
        'inputEl': [{ type: core_1.ViewChild, args: ['fileInput',] },],
    };
    return UploaderComponent;
}(base_1.BaseElement));
exports.UploaderComponent = UploaderComponent;
//# sourceMappingURL=uploader.component.js.map