"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("@angular/core");
var forms_1 = require("@angular/forms");
var models_1 = require("../../models");
var form_element_directive_1 = require("./form-element-directive");
var form_element_service_1 = require("./form-element.service");
var validators_service_1 = require("./validators.service");
var _ = require("lodash");
var FormElementComponent = /** @class */ (function () {
    function FormElementComponent(componentFactoryResolver, formElementService) {
        this.componentFactoryResolver = componentFactoryResolver;
        this.formElementService = formElementService;
        this.allowExternalControl = true;
        this.onChange = new core_1.EventEmitter();
        this.onKeyUp = new core_1.EventEmitter();
        this.onKeyPress = new core_1.EventEmitter();
        this.onBlur = new core_1.EventEmitter();
        this.hideElement = false;
        this.validatorsService = new validators_service_1.ValidatorsService();
    }
    FormElementComponent.prototype.ngOnInit = function () {
        this.controlName = this.field.name;
        if (!this.allowExternalControl || !this.form.controls[this.controlName]) {
            for (var i = 0; this.form.controls[this.controlName]; i++) {
                this.controlName = this.field.name + '_' + i;
            }
            var validators = [];
            if (this.field.validators) {
                if (_.isArray(this.field.validators)) {
                    validators = this.field.validators;
                }
                else if (_.isString(this.field.validators)) {
                    validators = (this.field.validators || '').split('|');
                }
            }
            this.form.addControl(this.controlName, new forms_1.FormControl('', this.validatorsService.getValidators(validators)));
        }
        this.formControl = this.form.controls[this.controlName];
        if (this.model && this.model instanceof models_1.Model) {
            this.model.setFormControl(this.field.name, this.formControl);
        }
    };
    FormElementComponent.prototype.ngOnChanges = function (changes) {
        if (this.componentRef) {
            this.componentRef.instance.data.model = this.model;
        }
    };
    FormElementComponent.prototype.ngAfterContentInit = function () {
        var casts = {
            boolean: 'slide-toggle',
            image: 'uploader',
            email: 'text',
            number: 'text',
            password: 'text',
            price: 'text',
            tel: 'text',
            time: 'text',
            date: 'text',
            url: 'text',
            week: 'text',
            text_editor: 'text',
            multiselect: 'select',
        };
        var type = typeof casts[this.field.type] == 'undefined' ? this.field.type : casts[this.field.type];
        var componentFactory = this.componentFactoryResolver.resolveComponentFactory(this.formElementService.getComponentClass(type));
        this.el.viewContainerRef.clear();
        this.componentRef = this.el.viewContainerRef.createComponent(componentFactory);
        this.componentRef.instance.data = {
            form: this.form,
            model: this.model,
            field: this.field,
            config: this.field.config,
            formControl: this.formControl,
            controlName: this.controlName,
            events: {
                onChange: this.onChange,
                onKeyUp: this.onKeyUp,
                onKeyPress: this.onKeyPress,
                onBlur: this.onBlur
            }
        };
        this.componentRef.instance.parseData();
        this.hideWhen();
    };
    FormElementComponent.prototype.hideWhen = function () {
        var _this = this;
        if (_.has(this.field.config, 'hide_when')) {
            var params = (this.field.config['hide_when'] || '').split('|');
            if (params.length) {
                var _loop_1 = function (param) {
                    var fields = (param || '').split(':');
                    if (fields[0] && fields[1]) {
                        setInterval(function () {
                            if (_this.model[fields[0]] == fields[1]) {
                                _this.formControl.disable();
                                _this.hideElement = true;
                                _this.model[_this.field.name]['__is_hidden'] = true;
                            }
                            else {
                                _this.formControl.enable();
                                _this.hideElement = false;
                                _this.model[_this.field.name]['__is_hidden'] = true;
                            }
                        }, 1000);
                    }
                };
                for (var _i = 0, params_1 = params; _i < params_1.length; _i++) {
                    var param = params_1[_i];
                    _loop_1(param);
                }
            }
        }
        else if (_.has(this.field.config, 'show_when')) {
            var params = (this.field.config['show_when'] || '').split('|');
            if (params.length) {
                var _loop_2 = function (param) {
                    var fields = (param || '').split(':');
                    if (fields[0] && fields[1]) {
                        setInterval(function () {
                            if (_this.model[fields[0]] == fields[1]) {
                                _this.formControl.enable();
                                _this.hideElement = false;
                                _this.model[_this.field.name]['__is_hidden'] = false;
                            }
                            else {
                                _this.formControl.disable();
                                _this.hideElement = true;
                                _this.model[_this.field.name]['__is_hidden'] = true;
                            }
                        }, 1000);
                    }
                };
                for (var _a = 0, params_2 = params; _a < params_2.length; _a++) {
                    var param = params_2[_a];
                    _loop_2(param);
                }
            }
        }
    };
    FormElementComponent.decorators = [
        { type: core_1.Component, args: [{
                    selector: 'gc-form-element',
                    template: "\n        <span [class.hide]=\"hideElement\">\n            <ng-template  gc-form-element></ng-template>\n        </span>\n    ",
                    styles: ["\n        .hide {\n            display: none;\n        }\n    "]
                },] },
    ];
    /** @nocollapse */
    FormElementComponent.ctorParameters = function () { return [
        { type: core_1.ComponentFactoryResolver, },
        { type: form_element_service_1.FormElementService, },
    ]; };
    FormElementComponent.propDecorators = {
        'el': [{ type: core_1.ViewChild, args: [form_element_directive_1.FormElementDirective,] },],
        'form': [{ type: core_1.Input, args: ['form',] },],
        'model': [{ type: core_1.Input, args: ['model',] },],
        'modelChange': [{ type: core_1.Output, args: ['modelChange',] },],
        'field': [{ type: core_1.Input, args: ['field',] },],
        'allowExternalControl': [{ type: core_1.Input, args: ['allowExternalControl',] },],
        'onChange': [{ type: core_1.Output, args: ['onChange',] },],
        'onKeyUp': [{ type: core_1.Output, args: ['onKeyUp',] },],
        'onKeyPress': [{ type: core_1.Output, args: ['onKeyPress',] },],
        'onBlur': [{ type: core_1.Output, args: ['onBlur',] },],
    };
    return FormElementComponent;
}());
exports.FormElementComponent = FormElementComponent;
//# sourceMappingURL=form-element.component.js.map