"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("@angular/core");
var createNumberMask_1 = require("text-mask-addons/dist/createNumberMask");
var emailMask_1 = require("text-mask-addons/dist/emailMask");
//import { conformToMask } from 'text-mask-core/dist/textMaskCore';
var createAutoCorrectedDatePipe_1 = require("text-mask-addons/dist/createAutoCorrectedDatePipe");
var MasksService = /** @class */ (function () {
    function MasksService() {
        var _this = this;
        this.externalMasks = [
            'cnpj',
            'cpf',
            'rg',
            'document',
            'cep',
            'phone',
            'cellphone',
            'number',
            'discount_percent',
            'phone_cellphone'
        ];
        this.masks = {
            currency: function (value, formControl) {
                if (value && !/[\d\.]+,\d{2}$/.test(value)) {
                    if (typeof value == 'number') {
                        value = value.toFixed(2);
                    }
                    value = parseInt(value.toString().replace(/\D/g, '')) || 0;
                    value = (value / 100).toFixed(2);
                    value = value.replace('.', ',').replace(/(\d)(?=(\d{3})+,)/g, '$1.');
                    value = 'R$ ' + value;
                    if (formControl) {
                        formControl.setValue(value);
                    }
                }
                return value;
            },
            cnpj: function () {
                return [/[1-9]/, /\d/, '.', /\d/, /\d/, /\d/, '.', /\d/, /\d/, /\d/, '/', /\d/, /\d/, /\d/, /\d/, '-', /\d/, /\d/];
            },
            cpf: function () {
                return [/\d/, /\d/, /\d/, '.', /\d/, /\d/, /\d/, '.', /\d/, /\d/, /\d/, '-', /\d/, /\d/];
            },
            rg: function () {
                return [/[1-9]/, /\d/, '.', /\d/, /\d/, /\d/, '.', /\d/, /\d/, /\d/, '-', /[1-9a-z]/];
            },
            document: function (rawValue) {
                var mask = [];
                if (rawValue.length <= 11) {
                    mask = _this.masks['cpf']();
                }
                else {
                    mask = _this.masks['cnpj']();
                }
                return mask;
            },
            cep: function () {
                return [/[0-9]/, /\d/, /\d/, /\d/, /\d/, '-', /\d/, /\d/, /\d/];
                //return [/[0-9]/, /\d/, /\d/, /\d/, /\d/, /\d/, /\d/,/\d/];
            },
            phone: function () {
                return ['(', /[1-9]/, /\d/, ')', ' ', /\d/, /\d/, /\d/, /\d/, '-', /\d/, /\d/, /\d/, /\d/];
                //return [/[1-9]/, /\d/,  /\d/, /\d/, /\d/, /\d/, /\d/, /\d/, /\d/, /\d/];
            },
            cellphone: function () {
                return ['(', /[1-9]/, /\d/, ')', ' ', /\d/, /\d/, /\d/, /\d/, /\d/, '-', /\d/, /\d/, /\d/, /\d/];
                //return [/[1-9]/, /\d/, /\d/, /\d/, /\d/, /\d/, /\d/, /\d/, /\d/, /\d/, /\d/];
            },
            number: createNumberMask_1.default({
                prefix: '',
                suffix: '',
                includeThousandsSeparator: false
            }),
            discount_percent: createNumberMask_1.default({
                prefix: '',
                suffix: '%',
                includeThousandsSeparator: false,
                allowDecimal: true,
                decimalSymbol: '.',
                decimalLimit: 2,
                integerLimit: 3
            }),
            phone_cellphone: function (rawValue) {
                var mask = [];
                if (rawValue.length <= 14) {
                    mask = _this.masks['phone']();
                }
                else {
                    mask = _this.masks['cellphone']();
                }
                return mask;
            },
            email: emailMask_1.default,
            date: {
                guide: true,
                mask: [/\d/, /\d/, '/', /\d/, /\d/, '/', /\d/, /\d/, /\d/, /\d/],
                pipe: createAutoCorrectedDatePipe_1.default('dd/mm/yyyy')
            }
        };
        this.unmasks = {
            cnpj: function (value) {
                return _this.normalizeValue(value).replace(/[\.\-\_\/]/gi, '');
            },
            cpf: function (value) {
                return _this.normalizeValue(value).replace(/[\.\-\_\/]/gi, '');
            },
            rg: function (value) {
                return this.normalizeValue(value).replace(/[\.\-\_\/]/gi, '');
            },
            document: function (value) {
                return _this.normalizeValue(value).replace(/[\.\-\_\/]/gi, '');
            },
            cep: function (value) {
                return _this.normalizeValue(value).replace(/\D/gi, '');
            },
            discount_percent: function (value) {
                return _this.normalizeValue(value)
                    .replace(' ', '')
                    .replace('%', '');
            },
            phone_cellphone: function (value) {
                return _this.normalizeValue(value).replace(/[\.\-\_\/\s\(\)]/gi, '');
            },
            date: function (value) {
                return _this.normalizeValue(value).replace(/\D/gi, '');
            },
            currency: function (value) {
                if (!value) {
                    return 0;
                }
                value = parseInt(value.toString().replace(/\D/g, ''));
                return (value / 100).toFixed(2);
            }
        };
    }
    MasksService.prototype.normalizeValue = function (value) {
        if (typeof value == 'undefined') {
            value = '';
        }
        return value.toString();
    };
    MasksService.prototype.getMask = function (name) {
        return this.masks[name] ? this.masks[name] : false;
    };
    MasksService.prototype.applyMask = function () {
        var args = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            args[_i] = arguments[_i];
        }
        if (this.masks[args[0]]) {
            if (this.externalMasks.indexOf(args[0]) > -1) {
                // let data: any = this.getMask(args[0]);
                // if(typeof data == 'function'){
                //     data = data(args[1]);
                // }
                // let value:any = conformToMask(args[1], data , {guide: false});
                //return value.conformedValue;
            }
            return this.masks[args[0]].apply(this, (args.slice(1)));
        }
    };
    MasksService.prototype.unmask = function (name, value) {
        return this.unmasks[name] ? this.unmasks[name](value) : value;
    };
    MasksService.decorators = [
        { type: core_1.Injectable },
    ];
    /** @nocollapse */
    MasksService.ctorParameters = function () { return []; };
    return MasksService;
}());
exports.MasksService = MasksService;
//# sourceMappingURL=masks.service.js.map