"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("@angular/core");
var forms_1 = require("@angular/forms");
var ValidatorsService = /** @class */ (function () {
    function ValidatorsService() {
        this.validators = {
            'min': function (min) {
                return forms_1.Validators.min(min);
            },
            'max': function (max) {
                return forms_1.Validators.max(max);
            },
            'min_length': function (min) {
                return forms_1.Validators.minLength(min);
            },
            'max_length': function (max) {
                return forms_1.Validators.maxLength(max);
            },
            'required': function () {
                return forms_1.Validators.required;
            },
            'required-true': function () {
                return forms_1.Validators.requiredTrue;
            },
            'email': function () {
                return forms_1.Validators.email;
            },
            'regex': function (pattern) {
                return forms_1.Validators.pattern(pattern);
            },
            'same': function same(otherKey) {
                return function (control) {
                    if (!control.parent) {
                        return null;
                    }
                    var otherControl = control.parent.get(otherKey);
                    if (!otherControl) {
                        return null;
                    }
                    var pass = control.value;
                    var confirmPass = otherControl.value;
                    return pass === confirmPass ? null : { notEquivalent: true };
                };
            }
        };
    }
    ValidatorsService.prototype.getValidator = function (name, param) {
        if (this.validators[name]) {
            return this.validators[name](param);
        }
        else {
            return false;
        }
    };
    ValidatorsService.prototype.getValidators = function (validators) {
        var _this = this;
        var arr = [];
        if (validators) {
            arr = validators.map(function (validator) {
                if (typeof validator == 'function') {
                    return validator;
                }
                var data = validator.split(':');
                return data.length > 1 ? _this.getValidator(data[0], data[1]) : _this.getValidator(validator);
            });
            arr = arr.filter(function (v) {
                return !(v === false);
            });
        }
        return arr;
    };
    ValidatorsService.decorators = [
        { type: core_1.Injectable },
    ];
    /** @nocollapse */
    ValidatorsService.ctorParameters = function () { return []; };
    return ValidatorsService;
}());
exports.ValidatorsService = ValidatorsService;
//# sourceMappingURL=validators.service.js.map