"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var collection_1 = require("../collections/collection");
var Model = /** @class */ (function () {
    function Model(data) {
        this.__primaryKey = 'id';
        this.__formControls = {};
        if (data) {
            this.fill(data);
        }
    }
    /* -------------- UTILS -------------- */
    Model.prototype.camelize = function (str) {
        return str.replace(/(?:^\w|[A-Z]|\b\w|_\w)/g, function (letter, index) {
            return index == 0 ? letter.toLowerCase() : letter.toUpperCase();
        }).replace(/[\s_]+/g, '');
    };
    /* -------------- COLLECTION -------------- */
    Model.newCollection = function (items) {
        return new this.__collection(items);
    };
    Object.defineProperty(Model, "resource", {
        /* -------------- RESOURCE -------------- */
        get: function () {
            if (!this.__resource) {
                var name_1 = this.name.toLocaleLowerCase();
                if (/(s|ch|sh|x|z)$/.test(name_1)) {
                    this.__resource = name_1.substr(0, name_1.length - 1) + 'es';
                }
                else if (/y$/.test(name_1)) {
                    this.__resource = name_1.substr(0, name_1.length - 1) + 'ies';
                }
                else if (/(f|fe)$/.test(name_1)) {
                    this.__resource = name_1.substr(0, name_1.length - 1) + 'ves';
                }
                else {
                    this.__resource = name_1 + 's';
                }
            }
            return this.__resource;
        },
        set: function (value) {
            this.__resource = value;
        },
        enumerable: true,
        configurable: true
    });
    /* -------------- KEY -------------- */
    Model.prototype.getPrimaryKey = function () {
        return this.__primaryKey;
    };
    Model.prototype.getId = function () {
        return this.get(this.getPrimaryKey());
    };
    Model.prototype.getKeyName = function () {
        return this.getPrimaryKey();
    };
    Model.prototype.getKey = function () {
        return this.getId();
    };
    /* -------------- FORM CONTROL -------------- */
    Model.prototype.setFormControl = function (name, control) {
        this.__formControls[name] = control;
    };
    Model.prototype.getFormControl = function (name) {
        return this.__formControls[name] ? this.__formControls[name] : null;
    };
    /* -------------- ATTRIBUTES -------------- */
    Model.prototype.get = function (name) {
        if (this.hasAccessor(name)) {
            return this.retrieve(name);
        }
        return this[name];
    };
    Model.prototype.set = function (name, value) {
        if (this.hasMutator(name)) {
            return this.mutate(name, value);
        }
        this[name] = value;
        return this;
    };
    Model.prototype.attr = function (name, value) {
        if (typeof value != 'undefined') {
            return this.set(name, value);
        }
        return this.get(name);
    };
    Model.prototype.fill = function (data) {
        for (var key in data) {
            this.attr(key, data[key]);
        }
    };
    Model.prototype.only = function () {
        var keys = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            keys[_i] = arguments[_i];
        }
        var obj = {}, self = this;
        keys.forEach(function (key) {
            if (self.hasOwnProperty(key) && key.indexOf('__') != 0) {
                obj[key] = self.get(key);
                if (obj[key] instanceof Object && obj[key].hasOwnProperty('_items')) {
                    obj[key] = self.get(key).getItems();
                }
            }
        });
        return obj;
    };
    Model.prototype.all = function () {
        var attributes = this.only.apply(this, Object.keys(this));
        for (var name_2 in attributes) {
            if (attributes[name_2] instanceof Model) {
                attributes[name_2] = attributes[name_2].all();
            }
            else if (attributes[name_2] instanceof Array) {
                attributes[name_2] = attributes[name_2].map(function (attr) {
                    return attr instanceof Model ? attr.all() : attr;
                });
            }
            else if (attributes[name_2] instanceof collection_1.Collection) {
                attributes[name_2] = attributes[name_2].getItems().map(function (attr) {
                    return attr instanceof Model ? attr.all() : attr;
                });
            }
        }
        return attributes;
    };
    /* --------------  ACCESSORS & MUTATORS -------------- */
    Model.prototype.hasMutator = function (attribute) {
        attribute = this.camelize(attribute.toString());
        attribute = attribute.charAt(0).toUpperCase() + attribute.substr(1);
        return (typeof this['set' + attribute + 'Attribute'] == 'function');
    };
    Model.prototype.hasAccessor = function (attribute) {
        attribute = this.camelize(attribute.toString());
        attribute = attribute.charAt(0).toUpperCase() + attribute.substr(1);
        return (typeof this['get' + attribute + 'Attribute'] == 'function');
    };
    Model.prototype.mutate = function (attribute, value) {
        attribute = this.camelize(attribute.toString());
        attribute = attribute.charAt(0).toUpperCase() + attribute.substr(1);
        this['set' + attribute + 'Attribute'](value);
        return this;
    };
    Model.prototype.retrieve = function (attribute) {
        attribute = this.camelize(attribute.toString());
        attribute = attribute.charAt(0).toUpperCase() + attribute.substr(1);
        return this['get' + attribute + 'Attribute']();
    };
    Model.__collection = collection_1.Collection;
    return Model;
}());
exports.Model = Model;
//# sourceMappingURL=model.js.map