"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("@angular/core");
var models_1 = require("../models");
var services_1 = require("../services");
var GuardService = /** @class */ (function () {
    function GuardService(router, authService, localStorageService, locationService) {
        this.router = router;
        this.authService = authService;
        this.localStorageService = localStorageService;
        this.locationService = locationService;
        this._model = models_1.Model;
        this._allowedUrls = {};
        this.init();
    }
    GuardService.prototype.init = function () {
        this.setAllowedUrls('login', 'register', 'forgot-password');
    };
    GuardService.prototype.setAllowedUrls = function () {
        var _this = this;
        var routes = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            routes[_i] = arguments[_i];
        }
        routes.forEach(function (route) {
            _this._allowedUrls[route] = _this.router.getUrl(route);
        });
    };
    GuardService.prototype.getAllowedUrls = function () {
        var arr = [];
        for (var i in this._allowedUrls) {
            arr.push(this._allowedUrls[i]);
        }
        return arr;
    };
    GuardService.prototype.getRedirectTo = function () {
        return 'panel.dashboard';
    };
    GuardService.prototype.getRedirectToUnauthenticated = function () {
        return 'login';
    };
    GuardService.prototype.canActivate = function (route, state) {
        if (this.authenticated) {
            if (this.getAllowedUrls().indexOf(state.url) > -1) {
                this.router.navigate(this.getRedirectTo());
            }
            return true;
        }
        var ok = false;
        this.getAllowedUrls().forEach(function (url) {
            var preg = new RegExp(url);
            if (preg.test(state.url)) {
                ok = true;
            }
        });
        if (!ok) {
            this.router.navigate([this.getRedirectToUnauthenticated(), {}]);
        }
        return true;
    };
    GuardService.prototype.getAuthService = function () {
        return this.authService;
    };
    GuardService.prototype.getTokenStorageKey = function () {
        return 'token';
    };
    GuardService.prototype.getUserStorageKey = function () {
        return 'user';
    };
    GuardService.prototype.afterLogout = function () {
        this.router.navigate('login');
    };
    GuardService.prototype.afterLogin = function () {
        var queries = this.locationService.getQueries();
        this.router.navigate(queries['returnUrl'] || this.getRedirectTo());
    };
    GuardService.prototype.loginUsing = function (response) {
        this.token = response.token;
        this.user = response.user;
        this.afterLogin();
    };
    GuardService.prototype.login = function (params, args) {
        var _this = this;
        return this.authService.login(params, args)
            .then(function (data) {
            _this.loginUsing(data.body.data);
            return data.body.data;
        });
    };
    GuardService.prototype.create = function (params, args) {
        var _this = this;
        return this.authService.create(params, args)
            .then(function (data) {
            _this.loginUsing(data.body.data);
            return data.body.data;
        });
    };
    GuardService.prototype.logout = function () {
        this.token = null;
        this.user = null;
        this.afterLogout();
    };
    Object.defineProperty(GuardService.prototype, "authenticated", {
        get: function () {
            return !!this.token;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(GuardService.prototype, "token", {
        get: function () {
            return this.localStorageService.get(this.getTokenStorageKey());
        },
        set: function (value) {
            if (value) {
                this.localStorageService.set(this.getTokenStorageKey(), value);
            }
            else {
                this.localStorageService.remove(this.getTokenStorageKey());
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(GuardService.prototype, "user", {
        get: function () {
            var data = this.localStorageService.get(this.getUserStorageKey());
            return new this._model(data);
        },
        set: function (value) {
            if (value) {
                this.localStorageService.set(this.getUserStorageKey(), value instanceof models_1.Model ? value.all() : value);
            }
            else if (this.localStorageService.has(this.getUserStorageKey())) {
                this.localStorageService.remove(this.getUserStorageKey());
            }
        },
        enumerable: true,
        configurable: true
    });
    GuardService.decorators = [
        { type: core_1.Injectable },
    ];
    /** @nocollapse */
    GuardService.ctorParameters = function () { return [
        { type: services_1.RouteService, },
        { type: services_1.AuthService, },
        { type: services_1.LocalStorageService, },
        { type: services_1.LocationService, },
    ]; };
    return GuardService;
}());
exports.GuardService = GuardService;
//# sourceMappingURL=guard.service.js.map