"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("@angular/core");
var http_1 = require("@angular/http");
var _1 = require("./");
require("rxjs/add/operator/toPromise");
var model_1 = require("../models/model");
var collection_1 = require("../collections/collection");
var HttpService = /** @class */ (function () {
    function HttpService(http, dialog) {
        this.http = http;
        this.dialog = dialog;
        this.headers = new http_1.Headers();
        this.setHeaders('Content-Type', 'application/json')
            .setHeaders('Accept', 'application/json');
        this.init();
    }
    HttpService.prototype.init = function () { };
    HttpService.prototype.ngAfterViewInit = function () { };
    HttpService.prototype.prepareOptions = function (options) {
        if (options === void 0) { options = {}; }
        if (options && typeof options.headers == 'undefined') {
            options.headers = this.getHeaders();
        }
        return options;
    };
    HttpService.prototype.mergeArgs = function (args) {
        var self = this;
        var data = {
            error: function (response) {
                self.handleError(response);
            },
            throwError: true,
            transformJson: true,
            apiUrl: this.apiUrl
        };
        for (var index in data) {
            if (typeof args[index] == 'undefined') {
                args[index] = data[index];
            }
        }
    };
    /**
     *
     * @param response Response
     * @return {any|Xhr}
     */
    HttpService.prototype.getError = function (data) {
        data = this.formatResponse(data);
        if (data.body.message) {
            data.body.error = data.body.message;
        }
        if (!data.body.error) {
            data.body.error = 'Error! Something went wrong';
        }
        return data;
    };
    HttpService.prototype.onError401 = function (error) { };
    HttpService.prototype.onError403 = function (error) { };
    HttpService.prototype.handleError = function (response) {
        if (response.response.status == 401) {
            this.onError401(response);
        }
        else if (response.response.status == 403) {
            this.onError403(response);
        }
        else {
            this.dialog.error(this.toSwalFormat(response.body))
                .then(function () { }, function () { });
        }
    };
    HttpService.prototype.normalizeRequestBody = function (body) {
        if (body) {
            if (body instanceof model_1.Model) {
                body = body.all();
            }
            else {
                for (var property in body) {
                    if (body.hasOwnProperty(property)) {
                        if (body[property] instanceof model_1.Model) {
                            body[property] = body[property].all();
                        }
                        else if (body[property] instanceof Array) {
                            body[property] = body[property].map(function (item) {
                                return item instanceof model_1.Model ? item.all() : item;
                            });
                        }
                        else if (body[property] instanceof collection_1.Collection) {
                            body[property] = body[property].getItems().map(function (item) {
                                return item instanceof model_1.Model ? item.all() : item;
                            });
                        }
                    }
                }
            }
        }
        return body;
    };
    HttpService.prototype.toSwalFormat = function (res) {
        var html = '';
        if (res.messages) {
            var li = '';
            for (var index in res.messages) {
                li += "<li>" + res.messages[index] + "</li>";
            }
            html = "<ul style=\"list-style: none\">" + li + "</ul>";
        }
        return {
            title: res.error,
            type: 'error',
            html: html,
            showCloseButton: true,
        };
    };
    HttpService.prototype.setAuthorization = function (token) {
        this.headers.set('Authorization', 'Bearer ' + token);
        return this;
    };
    HttpService.prototype.setHeaders = function (name, value) {
        this.headers.append(name, value);
        return this;
    };
    HttpService.prototype.getHeaders = function () {
        return this.headers;
    };
    HttpService.prototype.formatResponse = function (res) {
        var body;
        try {
            body = res.json();
        }
        catch (error) {
            body = { error: 'something went wrong' };
        }
        return {
            body: body,
            response: res
        };
    };
    HttpService.prototype.get = function (url, options, args) {
        var _this = this;
        if (options === void 0) { options = {}; }
        if (args === void 0) { args = {}; }
        this.mergeArgs(args);
        return new Promise(function (resolve, reject) {
            _this.http.get(args.apiUrl + url, _this.prepareOptions(options))
                .subscribe(function (res) {
                resolve(_this.formatResponse(res));
            }, function (res) {
                args.error(_this.getError(res));
                if (args.throwError) {
                    reject(res);
                }
            });
        });
    };
    HttpService.prototype.post = function (url, body, options, args) {
        var _this = this;
        if (options === void 0) { options = {}; }
        if (args === void 0) { args = {}; }
        this.mergeArgs(args);
        body = this.normalizeRequestBody(body);
        if (args['transformJson'])
            body = JSON.stringify(body);
        return new Promise(function (resolve, reject) {
            _this.http.post(args.apiUrl + url, body, _this.prepareOptions(options))
                .subscribe(function (res) {
                resolve(_this.formatResponse(res));
            }, function (res) {
                args.error(_this.getError(res));
                if (args.throwError) {
                    reject(res);
                }
            });
        });
    };
    HttpService.prototype.put = function (url, body, options, args) {
        var _this = this;
        if (options === void 0) { options = {}; }
        if (args === void 0) { args = {}; }
        this.mergeArgs(args);
        body = this.normalizeRequestBody(body);
        if (args['transformJson'])
            body = JSON.stringify(body);
        return new Promise(function (resolve, reject) {
            _this.http.put(args.apiUrl + url, body, _this.prepareOptions(options))
                .subscribe(function (res) {
                resolve(_this.formatResponse(res));
            }, function (res) {
                args.error(_this.getError(res));
                if (args.throwError) {
                    reject(res);
                }
            });
        });
    };
    HttpService.prototype.delete = function (url, options, args) {
        var _this = this;
        if (options === void 0) { options = {}; }
        if (args === void 0) { args = {}; }
        this.mergeArgs(args);
        return new Promise(function (resolve, reject) {
            _this.http.delete(args.apiUrl + url, _this.prepareOptions(options))
                .subscribe(function (res) {
                resolve(_this.formatResponse(res));
            }, function (res) {
                args.error(_this.getError(res));
                if (args.throwError) {
                    reject(res);
                }
            });
        });
    };
    HttpService.decorators = [
        { type: core_1.Injectable },
    ];
    /** @nocollapse */
    HttpService.ctorParameters = function () { return [
        { type: http_1.Http, },
        { type: _1.DialogService, },
    ]; };
    return HttpService;
}());
exports.HttpService = HttpService;
//# sourceMappingURL=http.service.js.map