"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("@angular/core");
var paginator_1 = require("../paginators/paginator");
var services_1 = require("../services");
require("rxjs/add/operator/map");
var RestfulService = /** @class */ (function () {
    function RestfulService(httpService) {
        this.httpService = httpService;
    }
    RestfulService.prototype.mapToCollection = function (list) {
        var _this = this;
        var collection = this.model.newCollection();
        list.data.forEach(function (item) {
            collection.add(_this.mapModel(item));
        });
        return collection;
    };
    RestfulService.prototype.mapModel = function (data) {
        return new this.model(data);
    };
    RestfulService.prototype.getUrl = function (id, params) {
        if (id === void 0) { id = null; }
        var resource = this.model.resource;
        if (params && (params.resource || params.resource === '')) {
            if (params.resource_concat) {
                resource = resource + '/' + params.resource;
            }
            else {
                resource = params.resource;
            }
        }
        return '/' + resource + (id ? '/' + id : '');
    };
    Object.defineProperty(RestfulService.prototype, "http", {
        get: function () {
            return this.httpService.http;
        },
        enumerable: true,
        configurable: true
    });
    RestfulService.prototype.getHeaders = function () {
        return this.httpService.getHeaders();
    };
    Object.defineProperty(RestfulService.prototype, "apiUrl", {
        get: function () {
            if (this._apiUrl) {
                return this._apiUrl;
            }
            return this.httpService.apiUrl;
        },
        set: function (value) {
            this._apiUrl = value;
        },
        enumerable: true,
        configurable: true
    });
    RestfulService.prototype.mergeArgs = function (args) {
        var data = {
            apiUrl: this.apiUrl,
            urlParams: null
        };
        for (var index in data) {
            if (typeof args[index] == 'undefined') {
                args[index] = data[index];
            }
        }
    };
    RestfulService.prototype.find = function (options, args) {
        var _this = this;
        if (options === void 0) { options = {}; }
        if (args === void 0) { args = {}; }
        this.mergeArgs(args);
        return this.httpService
            .get(this.getUrl(null, args.urlParams), options, args)
            .then(function (response) {
            if (args['originalResponse'])
                return response;
            var collection = _this.mapToCollection(response.body);
            if (response.body.current_page) {
                response.body.data = collection;
                return new paginator_1.Paginator(response.body);
            }
            else {
                return collection;
            }
        });
    };
    RestfulService.prototype.findById = function (id, options, args) {
        var _this = this;
        if (options === void 0) { options = {}; }
        if (args === void 0) { args = {}; }
        this.mergeArgs(args);
        return this.httpService
            .get(this.getUrl(id, args.urlParams), this.httpService.prepareOptions(options), args)
            .then(function (response) {
            if (args['originalResponse'])
                return response;
            if (args['isCollection']) {
                var collection = _this.mapToCollection(response.body);
                if (response.body.current_page) {
                    response.body.data = collection;
                    return new paginator_1.Paginator(response.body);
                }
                else {
                    return collection;
                }
            }
            else {
                return _this.mapModel(response.body.data);
            }
        });
    };
    RestfulService.prototype.create = function (data, options, args) {
        var _this = this;
        if (options === void 0) { options = {}; }
        if (args === void 0) { args = {}; }
        this.mergeArgs(args);
        return this.httpService
            .post(this.getUrl(null, args.urlParams), data, this.httpService.prepareOptions(options), args)
            .then(function (response) {
            if (args['originalResponse'])
                return response;
            if (response.response.status == 204)
                return null;
            return _this.mapModel(response.body.data);
        });
    };
    RestfulService.prototype.update = function (model, data, options, args) {
        var _this = this;
        if (options === void 0) { options = {}; }
        if (args === void 0) { args = {}; }
        this.mergeArgs(args);
        if (!data) {
            data = model.all();
        }
        return this.httpService
            .put(this.getUrl(model.getId(), args.urlParams), data, this.httpService.prepareOptions(options), args)
            .then(function (response) {
            if (args['originalResponse'])
                return response;
            if (response.response.status == 204)
                return null;
            return _this.mapModel(response.body.data);
        });
    };
    RestfulService.prototype.delete = function (model, options, args) {
        if (options === void 0) { options = {}; }
        if (args === void 0) { args = {}; }
        this.mergeArgs(args);
        return this.httpService
            .delete(this.getUrl(model.getId(), args.urlParams), this.httpService.prepareOptions(options), args)
            .then(function (response) {
            if (args['originalResponse'])
                return response;
            if (response.response.status == 204)
                return null;
            return null;
        });
    };
    RestfulService.decorators = [
        { type: core_1.Injectable },
    ];
    /** @nocollapse */
    RestfulService.ctorParameters = function () { return [
        { type: services_1.HttpService, },
    ]; };
    return RestfulService;
}());
exports.RestfulService = RestfulService;
//# sourceMappingURL=restful.service.js.map