"use strict";
var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("@angular/core");
var router_1 = require("@angular/router");
var _ = require("lodash");
function parseRoutes(objRoutes) {
    var routes = [];
    for (var k in objRoutes) {
        var objRoute = objRoutes[k], route = __assign({}, objRoute);
        if (route.children) {
            route.children = parseRoutes(route.children);
        }
        routes.push(__assign({}, route));
    }
    return routes;
}
exports.parseRoutes = parseRoutes;
var RouteHandler = /** @class */ (function () {
    function RouteHandler() {
    }
    RouteHandler.mergeParams = function (params, url) {
        if (typeof params == "object") {
            for (var param in params) {
                url = url.replace(':' + param, params[param]);
            }
        }
        return url;
    };
    RouteHandler.mapRoute = function (names, context) {
        var name = names.shift();
        if (name && context[name]) {
            return '/' + context[name]['path'] + this.mapRoute(names, context[name]['children']);
        }
        return name ? name : '';
    };
    RouteHandler.getArgs = function (data) {
        var routes = [], params = {}, options = {};
        if (typeof data == 'string') {
            routes = data.split('.');
        }
        else {
            routes = data[0].split('.');
            if (data[1]) {
                params = data[1];
            }
            if (data[2]) {
                options = data[2];
            }
        }
        var global = this.GLOBAL;
        return [
            [this.mergeParams(__assign({}, global, params), this.mapRoute(routes, this.ROUTES))],
            options
        ];
    };
    RouteHandler.GLOBAL = {};
    RouteHandler.ROUTES = {};
    return RouteHandler;
}());
var RouteService = /** @class */ (function () {
    function RouteService(router, activatedRoute) {
        var _this = this;
        this.router = router;
        this.activatedRoute = activatedRoute;
        this.changeParams = new core_1.EventEmitter();
        this.router.events
            .filter(function (event) { return event instanceof router_1.NavigationEnd; })
            .subscribe(function (event) {
            RouteHandler.GLOBAL = _this.loadParams(activatedRoute);
            _this.changeParams.emit(_this.getParams());
        });
    }
    RouteService.prototype.loadParams = function (activatedRoute) {
        var data = {};
        for (var arr = activatedRoute.root; arr; arr = arr.firstChild) {
            if (arr.snapshot) {
                var params = arr.snapshot.params;
                for (var key in params) {
                    data[key] = params[key];
                }
            }
        }
        return data;
    };
    RouteService.prototype.getParam = function (name) {
        return RouteHandler.GLOBAL[name];
    };
    RouteService.prototype.getParams = function () {
        return RouteHandler.GLOBAL;
    };
    RouteService.prototype.getUrl = function (args) {
        return this.router.createUrlTree.apply(this.router, RouteHandler.getArgs(args)).toString();
    };
    RouteService.prototype.navigate = function (args) {
        this.router.navigate([this.getUrl(args)]);
    };
    RouteService.prototype.navigateByUrl = function (url) {
        this.router.navigateByUrl(url);
    };
    RouteService.loadRoutes = function (objRoutes) {
        var routes = RouteHandler.ROUTES;
        RouteHandler.ROUTES = __assign({}, routes, objRoutes);
        return parseRoutes(objRoutes);
    };
    RouteService.transformRoutes = function (arrRoutes) {
        var routesNEW = {};
        for (var _i = 0, arrRoutes_1 = arrRoutes; _i < arrRoutes_1.length; _i++) {
            var val = arrRoutes_1[_i];
            if (val.children) {
                val.children = this.transformRoutes(val.children);
            }
            routesNEW[val.as] = val;
        }
        return routesNEW;
    };
    RouteService.addRoutes = function (arrRoutes) {
        var routes = RouteHandler.ROUTES;
        var routes2 = this.transformRoutes(_.cloneDeep(arrRoutes));
        RouteHandler.ROUTES = __assign({}, routes, routes2);
    };
    RouteService.decorators = [
        { type: core_1.Injectable },
    ];
    /** @nocollapse */
    RouteService.ctorParameters = function () { return [
        { type: router_1.Router, },
        { type: router_1.ActivatedRoute, },
    ]; };
    return RouteService;
}());
exports.RouteService = RouteService;
//# sourceMappingURL=route.service.js.map